@@ -17,7 +17,7 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 // Self
-#include <about.h>
+#include "about.h"
 
 // Local
 #include <version.h>
@@ -27,22 +27,27 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <KLocalizedString>
 
 // Qt
+#include <QString>
 
 namespace Gwenview
 {
 
-KAboutData* createAboutData(const QByteArray& appName, const QByteArray& catalogName, const KLocalizedString& programName)
+KAboutData* createAboutData(const QString& appName, const QString& programName)
 {
-    KAboutData* data = new KAboutData(appName, catalogName, programName, GWENVIEW_VERSION);
-    data->setLicense(KAboutData::License_GPL);
-    data->setCopyrightStatement(ki18n("Copyright 2000-2013 Gwenview authors"));
+    KAboutData* data = new KAboutData(appName, programName, GWENVIEW_VERSION);
+    data->setLicense(KAboutLicense::GPL);
+    data->setCopyrightStatement(i18n("Copyright 2000-2014 Gwenview authors"));
     data->addAuthor(
-        ki18n("Aurélien Gâteau"),
-        ki18n("Main developer"),
+        QStringLiteral("Lukáš Tinkl"),
+        i18n("Current Maintainer"),
+        "ltinkl@redhat.com");
+    data->addAuthor(
+        QStringLiteral("Aurélien Gâteau"),
+        i18n("Developer"),
         "agateau@kde.org");
     data->addAuthor(
-        ki18n("Benjamin Löwe"),
-        ki18n("Developer"),
+        QStringLiteral("Benjamin Löwe"),
+        i18n("Developer"),
         "benni@mytum.de");
     return data;
 }
