@@ -19,17 +19,17 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 */
 // Self
-#include "loadingindicator.moc"
+#include "loadingindicator.h"
 
 // Local
 
 // KDE
-#include <KDebug>
 #include <KPixmapSequence>
 
 // Qt
 #include <QPainter>
 #include <QTimer>
+#include <QDebug>
 
 namespace Gwenview
 {
