@@ -19,18 +19,17 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 */
 // Self
-#include <tagitemdelegate.moc>
+#include "tagitemdelegate.h"
 
 // Qt
 #include <QAbstractItemView>
 #include <QPainter>
 #include <QToolButton>
+#include <QDebug>
 
 // KDE
-#include <KDebug>
-#include <KDialog>
 #include <KIconLoader>
-#include <KLocale>
+#include <KLocalizedString>
 
 // Local
 #include <lib/semanticinfo/tagmodel.h>
@@ -50,7 +49,7 @@ TagItemDelegate::TagItemDelegate(QAbstractItemView* view)
     mButtonSize = qMax(sz.width(), sz.height());
 }
 
-QList<QWidget*> TagItemDelegate::createItemWidgets() const
+QList<QWidget*> TagItemDelegate::createItemWidgets(const QModelIndex &index) const
 {
 
 #define initButton(x) \
@@ -62,14 +61,14 @@ QList<QWidget*> TagItemDelegate::createItemWidgets() const
 
     QToolButton* assignToAllButton = new QToolButton;
     initButton(assignToAllButton);
-    assignToAllButton->setIcon(KIcon("fill-color")); /* FIXME: Probably not the appropriate icon */
+    assignToAllButton->setIcon(QIcon::fromTheme("fill-color")); /* FIXME: Probably not the appropriate icon */
     assignToAllButton->setToolTip(i18nc("@info:tooltip", "Assign this tag to all selected images"));
-    connect(assignToAllButton, SIGNAL(clicked()), SLOT(slotAssignToAllButtonClicked()));
+    connect(assignToAllButton, &QToolButton::clicked, this, &TagItemDelegate::slotAssignToAllButtonClicked);
 
     QToolButton* removeButton = new QToolButton;
     initButton(removeButton);
-    removeButton->setIcon(KIcon("list-remove"));
-    connect(removeButton, SIGNAL(clicked()), SLOT(slotRemoveButtonClicked()));
+    removeButton->setIcon(QIcon::fromTheme("list-remove"));
+    connect(removeButton, &QToolButton::clicked, this, &TagItemDelegate::slotRemoveButtonClicked);
 
 #undef initButton
 
@@ -132,7 +131,7 @@ void TagItemDelegate::slotRemoveButtonClicked()
 {
     const QModelIndex index = focusedIndex();
     if (!index.isValid()) {
-        kWarning() << "!index.isValid()";
+        qWarning() << "!index.isValid()";
         return;
     }
     emit removeTagRequested(index.data(TagModel::TagRole).toString());
@@ -142,7 +141,7 @@ void TagItemDelegate::slotAssignToAllButtonClicked()
 {
     const QModelIndex index = focusedIndex();
     if (!index.isValid()) {
-        kWarning() << "!index.isValid()";
+        qWarning() << "!index.isValid()";
         return;
     }
     emit assignTagToAllRequested(index.data(TagModel::TagRole).toString());
